@@ -2,7 +2,12 @@
 
 from typing import Optional
 from ...node import Node
-from ..semantic import filter_attributes, filter_empty, collapse_wrappers
+from ..semantic import (
+    filter_attributes,
+    filter_empty,
+    collapse_single_child_wrappers,
+    filter_presentational_roles,
+)
 
 
 def filter_semantic(node: Node) -> Optional[Node]:
@@ -10,8 +15,9 @@ def filter_semantic(node: Node) -> Optional[Node]:
     Apply all semantic filters.
 
     - Keeps only semantic attributes (role, aria-*, type, name, etc.)
+    - Filters presentational roles (removes role='none' or role='presentation')
     - Removes empty nodes (no attributes, no children)
-    - Collapses wrapper elements (single-child wrappers)
+    - Collapses single-child wrapper elements
 
     Args:
         node: Node to filter
@@ -28,6 +34,7 @@ def filter_semantic(node: Node) -> Optional[Node]:
         {'role': 'button'}
     """
     result = filter_attributes(node)
+    result = filter_presentational_roles(result) if result is not None else None
     result = filter_empty(result) if result is not None else None
-    result = collapse_wrappers(result) if result is not None else None
+    result = collapse_single_child_wrappers(result) if result is not None else None
     return result
